diff -u dired.el dired-2020-05-15b-PATCHED.el
--- dired.el	2020-05-15 11:23:32.804823800 -0700
+++ dired-2020-05-15b-PATCHED.el	2020-05-15 15:13:53.966204600 -0700
@@ -4114,22 +4114,45 @@
   "Non-nil means the Dired sort command is disabled.
 The idea is to set this buffer-locally in special Dired buffers.")
 
+(defcustom dired-switches-in-mode-line nil
+  "How to indicate `dired-actual-switches' in mode-line.
+Possible values:
+ * `nil':    Indicate name-or-date sort order, if possible.
+             Else show full switches.
+ * `as-is':  Show full switches.
+ * Integer:  Show only the first N chars of full switches.
+ * Function: Pass `dired-actual-switches' as arg and show result."
+  :group 'Dired-Plus
+  :type '(choice
+          (const    :tag "Indicate by name or date, else full"   nil)
+          (const    :tag "Show full switches"                    as-is)
+          (integer  :tag "Show first N chars of switches" :value 10)
+          (function :tag "Format with function"           :value identity)))
+
 (defun dired-sort-set-mode-line ()
-  ;; Set mode line display according to dired-actual-switches.
-  ;; Mode line display of "by name" or "by date" guarantees the user a
-  ;; match with the corresponding regexps.  Non-matching switches are
-  ;; shown literally.
+  "Set mode-line according to option `diredp-switches-in-mode-line'."
   (when (eq major-mode 'dired-mode)
     (setq mode-name
-	  (let (case-fold-search)
-	    (cond ((string-match-p
-		    dired-sort-by-name-regexp dired-actual-switches)
-		   "Dired by name")
-		  ((string-match-p
-		    dired-sort-by-date-regexp dired-actual-switches)
-		   "Dired by date")
-		  (t
-		   (concat "Dired " dired-actual-switches)))))
+	  (let ((case-fold-search  nil))
+            (if diredp-switches-in-mode-line
+                (concat "Dired"
+                        (cond ((integerp diredp-switches-in-mode-line)
+                               (let* ((l1  (length dired-actual-switches))
+                                      (xs  (substring dired-actual-switches
+                                                      0 (min l1 diredp-switches-in-mode-line)))
+                                      (l2  (length xs)))
+                                 (if (zerop l2)
+                                     xs
+                                   (concat " " xs (and (< l2  l1) "…")))))
+                              ((functionp diredp-switches-in-mode-line)
+                               (format " %s" (funcall diredp-switches-in-mode-line
+                                                     dired-actual-switches)))
+                              (t (concat " " dired-actual-switches))))
+              (cond ((string-match-p dired-sort-by-name-regexp dired-actual-switches)
+                     "Dired by name")
+                    ((string-match-p dired-sort-by-date-regexp dired-actual-switches)
+                     "Dired by date")
+                    (t (concat "Dired " dired-actual-switches))))))
     (force-mode-line-update)))
 
 (define-obsolete-function-alias 'dired-sort-set-modeline
